@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use CPAN::Meta;
 use Carp;
@@ -278,7 +278,7 @@ sub _build_repo {
 
     my ($repo)
         = ( $self->_git_config->{'remote.origin.url'} // q{} )
-        =~ m{github\.com[:/](.+?)(?:\.git)?$};
+        =~ m{github\.com[:/].+?/(.+?)(?:\.git)?$};
 
     $repo = IO::Prompt::Tiny::prompt( 'GitHub repo:', ( $repo // q{} ) )
         if $self->prompt;
@@ -743,7 +743,7 @@ RTx::ToGitHub - Convert rt.cpan.org tickets to GitHub issues
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
